==> breeze_website_builder_6.5.0.tar.gz: manage/upload_template_confirm.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
//
	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<title>Upload Template Confirm | Breeze Website Builder</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
<script>
	window.parent.document.title = document.title;
</script>
</head>

<body>

<table border="0" cellspacing="0" cellpadding="0" width="80%" style="width:80%;" align="center">
  <tr>
    <td colspan="2"><?php echo UPLOAD_TEMPLATE_CONFIRM_MSG; ?></td>
  </tr>
  <tr><td colspan="2" height="50" style="height:50px;">&nbsp;</td></tr>
  <tr>
	<td align="center">
    <div class='button_console_save' onClick="window.location='browse_template.php';" style="width:150px;"><span class='button_console_text_w_icon'><?php echo YES_WORD; ?></span></div>
    </td>
	<td align="center">
    <div class='button_console_cancel' onClick="window.location='dashboard.php';" style="width:150px;"><span class='button_console_text_w_icon'><?php echo NO_WORD; ?></span></div>
    </td>
  </tr>
  <tr>
  	<td align="center" colspan="2" style="padding-top:100px;">
    	<div class='button_console' style="width:200px;"><a href="http://itsabreezewebsitebuilder.com/wizard/wizard_step_1.php?cuic=itsabree&delete_all=Run%20Wizard%20and$20delete%20all%20pages" target="_blank" class="button_console_link"><span class='button_console_text'><?php echo GET_MORE_TEMPLATES_BTN; ?></span></a></div>
    </td>
  </tr>
</table>
</body>
</html>

==> breeze_website_builder_6.6.18.tar.gz: manage/upload_template_confirm.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
//
	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<title>Upload Template Confirm | Breeze Website Builder</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
<script>
	window.parent.document.title = document.title;
</script>
</head>

<body>

<table border="0" cellspacing="0" cellpadding="0" width="80%" style="width:80%;" align="center">
  <tr>
    <td colspan="2"><?php echo UPLOAD_TEMPLATE_CONFIRM_MSG; ?></td>
  </tr>
  <tr><td colspan="2" height="50" style="height:50px;">&nbsp;</td></tr>
  <tr>
	<td align="center">
    <div class='button_console_save' onClick="window.location='browse_template.php';" style="width:150px;"><span class='button_console_text_w_icon'><?php echo YES_WORD; ?></span></div>
    </td>
	<td align="center">
    <div class='button_console_cancel' onClick="window.location='dashboard.php';" style="width:150px;"><span class='button_console_text_w_icon'><?php echo NO_WORD; ?></span></div>
    </td>
  </tr>
  <tr>
  	<td align="center" colspan="2" style="padding-top:100px;">
    	<div class='button_console' style="width:200px;"><a href="<?php echo $http; ?>itsabreezewebsitebuilder.com/wizard/wizard_step_1.php?cuic=itsabree&delete_all=Run%20Wizard%20and$20delete%20all%20pages" target="_blank" class="button_console_link"><span class='button_console_text'><?php echo GET_MORE_TEMPLATES_BTN; ?></span></a></div>
    </td>
  </tr>
</table>
</body>
</html>
